@@ -16,6 +16,7 @@ from .errors import *
 from .models import *
 from .responses import *
 from .utils import *
+from .api.websocket import *
 
 __version__ = Configs.YAYLIB_VERSION
 __all__ = [
@@ -25,4 +26,8 @@ __all__ = [
     "models",
     "responses",
     "utils",
+    "MessageEventHandler",
+    "ChatRoomEventHandler",
+    "GroupUpdateEventHandler",
+    "GroupPostEventHandler",
 ]
