@@ -204,7 +204,7 @@ def invite_users_to_call(
     response = self._make_request(
         "POST",
         endpoint=f"{Endpoints.CALLS_V1}/conference_calls/{call_id}/invite",
-        payload={"call_id": call_id, "user_ids[]": user_ids},
+        payload={"call_id": call_id, "user_ids": user_ids},
         access_token=access_token,
     )
     self.logger.info("Invited users to call.")
@@ -288,6 +288,27 @@ def start_call(
     return response
 
 
+def start_anonymous_call(self, conference_id: int, agora_uid: str) -> ConferenceCall:
+    response = self._make_request(
+        "POST",
+        endpoint=f"{Endpoints.ANONYMOUS_CALLS_V1}/start_conference_call",
+        payload={"conference_id": conference_id, "agora_uid": agora_uid},
+        data_type=ConferenceCallResponse,
+    ).conference_call
+    self.logger.info("Joined the call.")
+    return response
+
+
+def stop__anonymous_call(self, conference_id: int, agora_uid: str = None):
+    response = self._make_request(
+        "POST",
+        endpoint=f"{Endpoints.ANONYMOUS_CALLS_V1}/leave_conference_call",
+        payload={"conference_id": conference_id, "agora_uid": agora_uid},
+    )
+    self.logger.info("Left the call.")
+    return response
+
+
 def stop_call(self, conference_id: int, call_sid: str = None, access_token: str = None):
     response = self._make_request(
         "POST",
