@@ -22,6 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+import hashlib
 from datetime import datetime
 from cryptography.fernet import Fernet
 
@@ -107,22 +108,43 @@ def is_valid_token(self, access_token: str):
 def login_with_email(
     self, email: str, password: str, secret_key: str = None
 ) -> LoginUserResponse:
+    """
+
+    メールアドレスでログインします
+
+    ローカルストレージのトークンの暗号化を利用するには、`Client` クラスの `encrypt_cookie` 引数を`True` に設定してください。
+
+    """
     if self.save_cookie_file:
-        cookies = self.load_cookies(email)
+        loaded_cookies = self.load_cookies()
+        hashed_email = hashlib.sha256(email.encode()).hexdigest()
 
-        if cookies is not None and secret_key is not None:
-            self.secret_key = secret_key
-            self.fernet = Fernet(secret_key)
-            self.cookies = self.decrypt_cookies(self.fernet, cookies)
-            self.session.headers.setdefault(
-                "Authorization", f"Bearer {self.access_token}"
+        if loaded_cookies is not None and loaded_cookies.get("email") == hashed_email:
+            if not self.encrypt_cookie:
+                self.cookies = loaded_cookies
+                # email property is reassigned here because it's hashed
+                self.email = email
+                self.session.headers.setdefault(
+                    "Authorization", f"Bearer {self.access_token}"
+                )
+                self.logger.info(f"Successfully logged in as '{self.user_id}'")
+                return LoginUserResponse(self.cookies)
+
+            if secret_key is not None:
+                self.secret_key = secret_key
+                self.fernet = Fernet(secret_key)
+                self.cookies = self.decrypt_cookies(self.fernet, loaded_cookies)
+                # email property is reassigned here because it's hashed
+                self.email = email
+                self.session.headers.setdefault(
+                    "Authorization", f"Bearer {self.access_token}"
+                )
+                self.logger.info(f"Successfully logged in as '{self.user_id}'")
+                return LoginUserResponse(self.cookies)
+
+            console_print(
+                f"{Colors.WARNING}Cookie データが見つかりました。「secret_key」を設定することにより、ログインレート制限を回避できます。{Colors.RESET}"
             )
-            self.logger.info(f"Successfully logged in as '{self.user_id}'")
-            return LoginUserResponse(cookies)
-
-        elif cookies is not None:
-            message = f"{Colors.WARNING}Cookie file found. The 'secret_key' must be provided to decrypt the credentials.{Colors.RESET}"
-            console_print(message)
 
     response = self._make_request(
         "POST",
@@ -142,25 +164,28 @@ def login_with_email(
     self.session.headers.setdefault("Authorization", f"Bearer {response.access_token}")
     self.logger.info(f"Successfully logged in as '{response.user_id}'")
 
+    self.cookies = {
+        "access_token": response.access_token,
+        "refresh_token": response.refresh_token,
+        "user_id": response.user_id,
+        "email": email,
+    }
+
     if self.save_cookie_file:
-        secret_key = Fernet.generate_key()
-        self.secret_key = secret_key.decode()
-        self.fernet = Fernet(secret_key)
+        if self.encrypt_cookie:
+            secret_key = Fernet.generate_key()
+            self.secret_key = secret_key.decode()
+            self.fernet = Fernet(secret_key)
 
-        console_print(
-            f"Your 'secret_key' for {Colors.BOLD + email + Colors.RESET} is: {Colors.OKGREEN + secret_key.decode() + Colors.RESET}",
-            "Please copy and securely store this key in a safe location.",
-            "For more information, visit: https://github.com/qvco/yaylib/blob/master/docs/API-Reference/login/login.md",
-        )
+            console_print(
+                f"Your 'secret_key' for {Colors.BOLD + email + Colors.RESET} is: {Colors.OKGREEN + secret_key.decode() + Colors.RESET}",
+                "Please copy and securely store this key in a safe location.",
+                "For more information, visit: https://github.com/qvco/yaylib/blob/master/docs/API-Reference/login/login.md",
+            )
 
-        self.cookies = {
-            "access_token": response.access_token,
-            "refresh_token": response.refresh_token,
-            "user_id": response.user_id,
-            "email": email,
-        }
-
-        self.save_cookies(self.cookies)
+        # copy the cookies to ensure its value remains unchanged during encryption
+        cookies = self.cookies.copy()
+        self.save_cookies(cookies)
 
     return response
 
