@@ -24,13 +24,13 @@ SOFTWARE.
 
 import os
 import httpx
-
+from io import BytesIO
 from PIL import Image
-from datetime import datetime
 from typing import List
+from urllib import parse
 
-from ..config import Endpoints
-from ..models import PresignedUrl
+from ..config import Endpoints, Configs
+from ..models import ApplicationConfig, Attachment, BanWord, PresignedUrl, PopularWord
 from ..responses import (
     EmailGrantTokenResponse,
     EmailVerificationPresignedUrlResponse,
@@ -39,7 +39,24 @@ from ..responses import (
     IdCheckerPresignedUrlResponse,
     VerifyDeviceResponse,
     WebSocketTokenResponse,
+    ApplicationConfigResponse,
+    BanWordsResponse,
+    PopularWordsResponse,
 )
+from ..utils import is_valid_image_format, get_hashed_filename
+
+
+upload_item_types = [
+    "post",
+    "chat_message",
+    "chat_background",
+    "report",
+    "user_avatar",
+    "user_cover",
+    "group_cover",
+    "group_thread_icon",
+    "group_icon",
+]
 
 
 def accept_policy_agreement(self, type: str, access_token: str = None):
@@ -186,47 +203,139 @@ def verify_device(
     return response
 
 
-def upload_image(
-    self, image_type: str, image_path: str, access_token: str = None
-) -> str:
+def upload_image(self, image_paths: List[str], image_type: str) -> List[Attachment]:
     """
 
-    画像をアップロードしてattachment_filenameを返します。
+    画像をアップロードして、サーバー上のファイル名のリストを返します。
 
     Parameteres
     -----------
+
+        - image_path: List[str] - (required): 画像パスのリスト
         - image_type: str - (required): 画像の種類
-        - image_path: str - (required): "画像のパス
+
+    Examples
+    --------
+
+    投稿に画像を付与する場合
+
+    >>> # サーバー上にアップロード
+    >>> attachments = api.upload_image(
+    >>>     image_type=yaylib.IMAGE_TYPE_POST,
+    >>>     image_paths=["./test.jpg"],
+    >>> )
+    >>> # サーバー上のファイル名を指定
+    >>> api.create_post(
+    >>>     "Hello with yaylib!",
+    >>>     attachment_filename=attachments[0].filename
+    >>> )
 
     """
-    date = datetime.now()
-    timestamp = int(date.timestamp() * 1000)
-    filename, ext = os.path.splitext(image_path)
+    if image_type not in upload_item_types:
+        raise TypeError(f"Invalid image type. [{image_type}]")
 
-    with Image.open(image_path) as image:
-        width, height = image.size
+    _files = []
 
-    base_url = f"{image_type}/{date.year}/{date.month}/{date.day}"
-    mid_url = f"{filename}_{timestamp}_0_size_"
-    original_url = f"{base_url}/{mid_url}{width}x{height}{ext}"
-    thumb_url = f"{base_url}/thumb_{mid_url}{width}x{height}{ext}"
+    for key, image_path in enumerate(image_paths):
+        filename, extension = os.path.splitext(image_path)
 
-    presigned_urls = get_file_upload_presigned_urls(
-        self, [original_url, thumb_url], access_token=access_token
-    )
+        if not is_valid_image_format(extension):
+            raise ValueError(f"Invalid image format. [{filename + extension}]")
 
-    with open(image_path, "rb") as f:
-        response = httpx.put(presigned_urls[0].url, data=f.read())
+        image = Image.open(image_path)
+        natural_width, natural_height = image.size
+        resized_image = image
+
+        if extension != ".gif":
+            resized_image.thumbnail((450, 450))
+
+        original_attachment = Attachment(
+            file=image,
+            filename="",
+            original_file_name=filename,
+            original_file_extension=extension,
+            natural_width=natural_width,
+            natural_height=natural_height,
+            is_thumb=False,
+        )
+
+        thumbnail_attachment = Attachment(
+            file=resized_image,
+            filename="",
+            original_file_name=filename,
+            original_file_extension=extension,
+            natural_width=natural_width,
+            natural_height=natural_height,
+            is_thumb=True,
+        )
+
+        uuid = self.generate_uuid()[:8]
+
+        original_attachment.filename = get_hashed_filename(
+            original_attachment, image_type, key, uuid
+        )
+        thumbnail_attachment.filename = get_hashed_filename(
+            thumbnail_attachment, image_type, key, uuid
+        )
+
+        _files.append(original_attachment)
+        _files.append(thumbnail_attachment)
+
+    file_names = [x.filename for x in _files]
+    res_presigned_url = get_file_upload_presigned_urls(self, file_names)
+
+    res_upload = []
+
+    for x in _files:
+        p_url = next(
+            (p.url for p in res_presigned_url if x.filename in p.filename), None
+        )
+        if not p_url:
+            continue
+
+        image_data = BytesIO()
+        image.save(image_data, format=x.file.format)
+        image_data.seek(0)
+
+        response = httpx.put(p_url, data=image_data.read())
         response.raise_for_status()
 
-    with open(image_path, "rb") as f:
-        response = httpx.put(presigned_urls[1].url, data=f.read())
-        response.raise_for_status()
+        x.filename = parse.urlsplit(p_url).path.replace("/uploads/", "")
 
-    self.logger.info(f"Image '{filename}{ext}' is uploaded")
+        res_upload.append(x)
 
-    return presigned_urls[0].filename
+    return res_upload
 
 
 def upload_video(self, video_path: str, access_token: str = None):
     pass
+
+
+# config
+
+
+def get_app_config(self) -> ApplicationConfig:
+    response = self._make_request(
+        "GET",
+        endpoint=f"https://{Configs.YAY_CONFIG_HOST}/api/apps/yay",
+        data_type=ApplicationConfigResponse,
+    ).app
+    return response
+
+
+def get_banned_words(self, country_code: str = "jp") -> List[BanWord]:
+    response = self._make_request(
+        "GET",
+        endpoint=f"https://{Configs.YAY_CONFIG_HOST}/{country_code}/api/v2/banned_words",
+        data_type=BanWordsResponse,
+    ).ban_words
+    return response
+
+
+def get_popular_words(self, country_code: str = "jp") -> List[PopularWord]:
+    response = self._make_request(
+        "GET",
+        endpoint=f"https://{Configs.YAY_CONFIG_HOST}/{country_code}/api/apps/yay/popular_words",
+        data_type=PopularWordsResponse,
+    ).popular_words
+    return response
