@@ -148,6 +148,9 @@ from .api.misc import (
     verify_device,
     upload_image,
     upload_video,
+    get_app_config,
+    get_banned_words,
+    get_popular_words,
 )
 from .api.post import (
     add_bookmark,
@@ -263,6 +266,9 @@ from .api.user import (
     unhide_users,
 )
 from .models import (
+    ApplicationConfig,
+    Attachment,
+    BanWord,
     Bgm,
     ChatRoom,
     ConferenceCall,
@@ -273,6 +279,7 @@ from .models import (
     Message,
     Post,
     PresignedUrl,
+    PopularWord,
     SharedUrl,
     StickerPack,
     Survey,
@@ -321,6 +328,70 @@ from .responses import (
 )
 
 
+POST_TYPE_TEXT = "text"
+r""" `text`: テキストのみ投稿タイプ"""
+
+POST_TYPE_MEDIA = "media"
+r""" `media`: メディアを含める投稿タイプ"""
+
+POST_TYPE_IMAGE = "image"
+r""" `image`: 画像を含める投稿タイプ"""
+
+POST_TYPE_VIDEO = "video"
+r""" `video`: ビデオを含める投稿タイプ"""
+
+POST_TYPE_SURVEY = "survey"
+r""" `survey`: アンケートを含める投稿タイプ"""
+
+POST_TYPE_CALL = "call"
+r""" `call`: 通話用の投稿タイプ"""
+
+POST_TYPE_SHAREABLE_URL = "shareable_url"
+r""" `shareable_url`: サークルやスレッド共有用の投稿タイプ"""
+
+
+CALL_TYPE_VOICE = "voice"
+r""" `voice`: 音声通話用の通話タイプ"""
+
+CALL_TYPE_VIDEO = "vdo"
+r""" `vdo`: ビデオ通話用の通話タイプ"""
+
+
+IMAGE_TYPE_POST = "post"
+r""" `post`: 投稿に画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_CHAT_MESSAGE = "chat_message"
+r""" `chat_message`: 個人チャットに画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_CHAT_BACKGROUND = "chat_background"
+r""" `chat_background`: 個人チャットの背景用に画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_REPORT = "report"
+r""" `report`: 通報用の画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_USER_AVATAR = "user_avatar"
+r""" `user_avatar`: プロフィール画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_USER_COVER = "user_cover"
+r""" `user_cover`: プロフィールの背景画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_GROUP_COVER = "group_cover"
+r""" `group_cover`: グループの背景画像をアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_GROUP_THREAD_ICON = "group_thread_icon"
+r""" `group_thread_icon`: グループ内のスレッド用アイコンをアップロードする際の画像タイプ"""
+
+IMAGE_TYPE_GROUP_ICON = "group_icon"
+r""" `group_icon`: グループのアイコンをアップロードする際の画像タイプ"""
+
+
+SHAREABLE_TYPE_GROUP = "group"
+r""" `group`: サークル用の共有タイプ"""
+
+SHAREABLE_TYPE_THREAD = "thread"
+r""" `thread`: スレッド用の共有タイプ"""
+
+
 class Client(API):
     """
 
@@ -341,6 +412,7 @@ class Client(API):
         - err_lang: str - (optional)
         - base_path: str - (optional)
         - save_cookie_file: bool - (optional)
+        - encrypt_cookie: bool - (optional)
         - cookie_filename: str - (optional)
         - loglevel: int - (optional)
 
@@ -1569,6 +1641,9 @@ class Client(API):
 
         メールアドレスでログインします
 
+        ※ ローカルストレージのトークンの暗号化を利用するには、`Client` クラスの `encrypt_cookie` 引数を`True` に設定してください。
+
+
         """
         return login_with_email(self, email, password, secret_key)
 
@@ -1694,20 +1769,59 @@ class Client(API):
         """
         return get_web_socket_token(self, headers, access_token)
 
-    def upload_image(
-        self, image_type: str, image_path: str, access_token: str = None
-    ) -> str:
+    def upload_image(self, image_paths: List[str], image_type: str) -> List[Attachment]:
         """
 
-        画像をアップロードしてattachment_filenameを返します。
+        画像をアップロードして、サーバー上のファイル名のリストを返します。
 
         Parameteres
         -----------
+
+            - image_path: List[str] - (required): 画像パスのリスト
             - image_type: str - (required): 画像の種類
-            - image_path: str - (required): "画像のパス
+
+        Examples
+        --------
+
+        投稿に画像を付与する場合
+
+        >>> # サーバー上にアップロード
+        >>> attachments = api.upload_image(
+        >>>     image_type=yaylib.IMAGE_TYPE_POST,
+        >>>     image_paths=["./test.jpg"],
+        >>> )
+        >>> # サーバー上のファイル名を指定
+        >>> api.create_post(
+        >>>     "Hello with yaylib!",
+        >>>     attachment_filename=attachments[0].filename
+        >>> )
 
         """
-        return upload_image(self, image_type, image_path, access_token)
+        return upload_image(self, image_paths, image_type)
+
+    def get_app_config(self) -> ApplicationConfig:
+        """
+
+        アプリケーションの設定情報を取得します
+
+        """
+        return get_app_config(self)
+
+    def get_banned_words(self, country_code: str = "jp") -> List[BanWord]:
+        """
+
+        禁止ワードの一覧を取得します
+
+        """
+        return get_banned_words(self, country_code)
+
+    def get_popular_words(self, country_code: str = "jp") -> List[PopularWord]:
+        """
+
+        人気のワードの一覧を取得します
+
+        """
+        return get_popular_words(self, country_code)
 
     # -POST
 
@@ -2810,7 +2924,7 @@ class Client(API):
 
         ユーザーのフォロワーランキングを取得します
 
-        Examples:
+        Examples
         --------
 
         >>> ルーキーを取得する場合:
