@@ -26,7 +26,7 @@ from enum import Enum
 
 
 class Configs:
-    YAYLIB_VERSION = "1.0.9"
+    YAYLIB_VERSION = "1.1.2"
     YAY_API_VERSION = "3.21"
     YAY_VERSION_NAME = "3.21.0"
     YAY_API_VERSION_KEY = "c687e24f6a454896891acd68868c7979"
@@ -40,6 +40,7 @@ class Configs:
     YAY_STAGING_HOST_1 = "stg.yay.space"
     YAY_STAGING_HOST_2 = "cas.yay.space"
     YAY_CABLE_HOST = "cable.yay.space"
+    YAY_CONFIG_HOST = "settings.yay.space"
     YAY_PRODUCTION_HOST = "api.yay.space"
     ID_CARD_CHECK_HOST_PRODUCTION = "idcardcheck.com"
     ID_CARD_CHECK_HOST_STAGING = "stg.idcardcheck.com"
@@ -256,7 +257,6 @@ class ErrorType(Enum):
 
 class ErrorMessage(Enum):
     Unknown = "原因不明"
-    # InvalidParameter = "引数が不正です"
     RegisteredUser = "このアカウントはすでに登録されています"
     AccessTokenExpired = "アクセストークンの有効期限切れ"
     ScreenNameAlreadyBeenTaken = "このIDはすでに使われています"
