@@ -24,6 +24,8 @@ SOFTWARE.
 
 from .models import (
     Activity,
+    ApplicationConfig,
+    ApplicationConfigSettings,
     BanWord,
     Bgm,
     CallGiftHistory,
@@ -1228,3 +1230,47 @@ class WebSocketTokenResponse:
 
     def __repr__(self):
         return f"WebSocketTokenResponse(data={self.data})"
+
+
+class ApplicationConfigResponse:
+    __slots__ = ("data", "app")
+
+    def __init__(self, data):
+        self.data = data
+
+        self.app = data.get("app")
+        if self.app is not None:
+            self.app = ApplicationConfig(self.app)
+
+    def __repr__(self):
+        return f"ApplicationConfigResponse(data={self.data})"
+
+
+class BanWordsResponse:
+    __slots__ = ("data", "ban_words")
+
+    def __init__(self, data):
+        self.data = data
+
+        self.ban_words = data.get("ban_words")
+        if self.ban_words is not None:
+            self.ban_words = [BanWord(ban_word) for ban_word in self.ban_words]
+
+    def __repr__(self):
+        return f"BanWordsResponse(data={self.data})"
+
+
+class PopularWordsResponse:
+    __slots__ = ("data", "popular_words")
+
+    def __init__(self, data):
+        self.data = data
+
+        self.popular_words = data.get("popular_words")
+        if self.popular_words is not None:
+            self.popular_words = [
+                PopularWord(popular_word) for popular_word in self.popular_words
+            ]
+
+    def __repr__(self):
+        return f"PopularWordsResponse(data={self.data})"
