@@ -22,6 +22,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+import re
 from datetime import datetime
 
 
@@ -48,3 +49,21 @@ def parse_datetime(timestamp: int) -> str:
     if timestamp is not None:
         return str(datetime.fromtimestamp(timestamp))
     return timestamp
+
+
+def is_valid_image_format(format):
+    is_valid = bool(re.match(r".jpg|.jpeg|.png|.gif", format))
+    return is_valid
+
+
+def get_hashed_filename(att, type, key, uuid):
+    today = datetime.now()
+    full_date = today.strftime("%Y/%m/%d")
+    thumbnail = "thumb_" if att.is_thumb else ""
+    file_name = f"{thumbnail}{uuid}_{int(today.timestamp())}_{key}"
+    sizes = f"_size_{att.natural_width}x{att.natural_height}"
+    extension = f"{att.original_file_extension}"
+
+    hashed_filename = f"{type}/{full_date}/{file_name}{sizes}{extension}"
+
+    return hashed_filename
